@@ -22,7 +22,7 @@ from pynamodb.constants import (
     WRITE_CAPACITY_UNITS, GLOBAL_SECONDARY_INDEXES, PROJECTION, EXCLUSIVE_START_TABLE_NAME, TOTAL,
     DELETE_TABLE, UPDATE_TABLE, LIST_TABLES, GLOBAL_SECONDARY_INDEX_UPDATES, HTTP_BAD_REQUEST,
     CONSUMED_CAPACITY, CAPACITY_UNITS
-    )
+)
 
 
 log = logging.getLogger(__name__)
@@ -174,9 +174,6 @@ class Connection(object):
     """
 
     def __init__(self, region=None, host=None):
-        self._endpoint = None
-        self._session = None
-        self._service = None
         self._tables = {}
         self.host = host
         if region:
@@ -242,25 +239,20 @@ class Connection(object):
         """
         Returns a valid botocore session
         """
-        if self._session is None:
-            self._session = get_session()
-        return self._session
+        return get_session()
 
     @property
     def service(self):
         """
         Returns a reference to the dynamodb service
         """
-        if self._service is None:
-            self._service = self.session.get_service(SERVICE_NAME)
-        return self._service
+        return self.session.get_service(SERVICE_NAME)
 
     @property
     def endpoint(self):
         """
         Returns an endpoint connection to `self.region`
         """
-        end_point = None
         if self.host:
             end_point = self.service.get_endpoint(self.region, endpoint_url=self.host)
         else:
